//-----------------------------------------------------------------------------
//
//						XMM Science Analysis System (SAS)
//                     (c) 1997-2010 European Space Agency
//
//-----------------------------------------------------------------------------
//
//	gtimerge.cc: merge a list of GTIs into one
//
//	DESCRIPTION:
//		The task takes a list of input GTI tables, merges them (logical
//		AND or OR) and writes the resulting new GTI table to a new data
//		set.
//
//	CHANGE HISTORY:
//		UL, 2000-02-16: 1.0.0: - initial version
//		UL, 2000-05-25: 1.1.0: - new parameters 'withgtitable'/'gtitable'
//		UL, 2001-05-30: 1.2.0: - add warning message in case of empty
//								 result GTI table (as described in doc)
//
//	AUTHOR:
//		U. Lammers, Wed Feb 16 17:27:23 MET 2000
//
//	REFERENCES:
//		[1]: Software Specification Document for the XMM Science Analysis
//			 Subsystem, M. Dahlem et. al., 
//
//	$Header: /data/xmm12/cvsadmin/soc_repos/task_devel/packages/gtimerge/src/gtimerge.cc,v 1.4 2001/05/30 11:31:19 ulammers Exp $

#include "param.h"
#include "stringutil.h"
#include "OGIPgti.h"

#include "gtimerge.h"

void gtimerge()
{
	vector<string> inTableNames(stringListParameter("tables"));
	if (!inTableNames.size())
		errstr<<"Need at least one GTI table"<<Sas::error("NoGtiTables");

	GtiList mergedList;
	{
		InOGIPgtiTable gtiTab(inTableNames[0]);
		gtiTab>>mergedList;
	}

	bool orMode = uppercase(stringParameter("mergemode")) == "OR";
	for (unsigned n=1; n<inTableNames.size(); ++n) {
		InOGIPgtiTable inTab(inTableNames[n]);
		GtiList gl;
		inTab>>gl;

		if (orMode)
			mergedList |= gl;
		else
			mergedList &= gl;
	}

	OutOGIPgtiTable outTab(booleanParameter("withgtitable")
							? stringParameter("gtitable")
							: inTableNames[0]);

	if (mergedList.empty())
		errstr<<"The list of GTIs resulting from the merging of all input "
				"GTIs is empty. Filtering with this empty list will yield "
				"a likewise empty output table."
			  <<Sas::warning("EmptyOutputGTItable");

	outTab<<mergedList;
} // gtimerge()

